import pandas as pd
import matplotlib.pyplot as plt
import geopandas as gpd
from shapely import wkb
from markdown_pdf import MarkdownPdf, Section


def function(rows):
    df = pd.DataFrame(rows)

    # bar graph plot
    states = ['Light', 'Minor', 'Moderate', 'Severe', 'Collapse']
    total_count = [sum([region['count'] for region in df[state]]) for state in states]

    plt.bar(states, total_count)
    plt.title('Number of damaged buildings')
    # also add the total count as a label
    for i, y in enumerate(total_count):
        plt.text(i, y, y, ha='center')
    plt.savefig(model_output('building-damage-states.png'))

    # choropleth map output
    geometry = [wkb.loads(row['the_geom'][0]) for row in df['Region']]
    gdf = gpd.GeoDataFrame(df, crs="EPSG:4326", geometry=geometry)

    ax = gdf.plot(column='Collapsed', cmap='Reds', legend=True)
    # labels
    gdf.apply(lambda x: ax.annotate(text=x['Region']['Region'], xy=x.geometry.centroid.coords[0], ha='center', size=5),
              axis=1)
    ax.set_axis_off()
    ax.set_title('Collapsed buildings in Upolu by region')
    plt.savefig(model_output('regional-collapsed-buildings.png'))

    # PDF report
    create_PDF_report(df, model_output('Report-Summary.pdf'))


def create_PDF_report(df, report_name):
    states = ['None', 'Light', 'Minor', 'Moderate', 'Severe', 'Collapse']
    totals = {}
    total_damaged = 0
    for state in states:
        totals[state] = sum([region['count'] for region in df[state]])
        if state != 'None':
            total_damaged += totals[state]

    with open("template.md") as template:
        text = template.read().format(
            total_damaged=total_damaged,
            total_buildings=sum(totals.values()),
            total_collapsed=totals['Collapse']
        )

    # Table
    table = df[["Region", "Collapsed"]].copy()
    table["Region"] = table["Region"].map(lambda x: x["Region"])

    text += "\n" + table.to_markdown(index=False)

    pdf = MarkdownPdf()
    pdf.add_section(Section(text))
    pdf.save(report_name)
